

Execution Profiling
===================

.. automodule:: profiling
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

    profiling.gedaif
    profiling.sourcing
    profiling.entityhub


Profiling Infrastructure
------------------------

.. toctree::

   profiling.profiler
   profiling.run
